/* GE OCt94 proc to return Bonferroni confidence intervals using the
matrices held in /FMT.


Input :   cl,cu    : upper and lower (1-a1)% confidence intervals
                     from first stage
          a2       : second stage size
          aa1      : ces3 matrix (lower)
          aa2      : ces3 matrix (upper)
          delt     : estimate of delta

Output    bl,bu    : upper and lower (1-a2)% confidence intervals

e.g.  proc(1) = bonf1(-10|0.4,8,0.8);
   this will return the bonferroni cv's where the first stage test size
   was 2% and the second 8% (overall 10%) when delta is 0.8.
*/

proc(1) = bonf1(cc,a2,ss1,ss2,delt);

local cl, cu, e1, indl, br, e2, indu, tr,
      e, cv1, cv2, p1, p2, pct, coll, colu,
      cvl1, cvu1, cvl2, cvu2, xv, cvl, cvu;


@ Select Range of c to consider @
@ deals with endpoints @
cl=cc[1,1];
if cl<-39.9; cl=-39.9; endif;
cu=cc[2,1];
if cu>9.4; cu=9.4; endif;
if cu<-39.9; cv1=ss1[1,.]; cv2=ss2[1,.]; goto endpt; endif;

@ selects dist of tgamm inside 1st stage -do for upper and lower@
if abs(delt)>=0.1;

e1=ss1[.,1].<cl;
if cl>-39.9;
indl=sumc(e1);
br=lint(cl,ss1[indl:indl+1,.],ss1[indl:indl+1,1]);
endif;

e2=ss1[.,1].>cu;
if cu<9.4;
indu=rows(ss1)-sumc(e2);
tr=lint(cu,ss1[indu:indu+1,.],ss1[indu:indu+1,1]);
endif;
e=e1+e2;
e=ones(rows(e),1)-e;
cv1=selif(ss1,e);

if cl>-39.9;
cv1=br|cv1;
endif;
if cu<9.4;
cv1=cv1|tr;
endif;

 else;
 cv1=ss1[1,.];
 endif;


e1=ss2[.,1].<cl;
if cl>-39.9;
indl=sumc(e1);
br=lint(cl,ss2[indl:indl+1,.],ss2[indl:indl+1,1]);
endif;

e2=ss2[.,1].>cu;
if cu<9.4;
indu=rows(ss2)-sumc(e2);
tr=lint(cu,ss2[indu:indu+1,.],ss2[indu:indu+1,1]);
endif;
e=e1+e2;
e=ones(rows(e),1)-e;
cv2=selif(ss2,e);

if cl>-39.9;
cv2=br|cv2;
endif;
if cu<9.4;
cv2=cv2|tr;
endif;

endpt:

@ find column number for correct size @
p1=seqa(0.005,0.005,20);
p2=seqa(0.90,0.005,20);
pct=p1|0.5|p2;
pct=round(1000*pct)/1000;
coll=indnv(round(1000*(a2/2))/1000,pct)+1;
colu=indnv(round(1000*(1-(a2/2)))/1000,pct)+1;

cvl1=(cv1[.,coll]);
cvu1=(cv1[.,colu]);
cvl2=(cv2[.,coll]);
cvu2=(cv2[.,colu]);

if abs(delt)<0.1;
   cvl1=cvl1.*ones(rows(cvl2),1);
   cvu1=cvu1.*ones(rows(cvu2),1);
endif;

@ interpolate according to delta @
xv=floor(delt*10)|ceil(delt*10);
if (10*delt)==xv[1,1]; cvl=cvl1';  cvu=cvu1';
elseif (10*delt)==xv[2,1]; cvl=cvl2'; cvu=cvu2';
else;
{cvl} = lint(delt*10,(cvl1')|(cvl2'),xv);
{cvu} = lint(delt*10,(cvu1')|(cvu2'),xv);
endif;

cvl=minc(cvl');
cvu=maxc(cvu');

retp(sortc((delt/abs(delt)).*(cvl|cvu),1));
endp;

/*
/* debug */
ci1=-20|-1;
dhat1=-0.05;
load path=fmt aa1=ces3_0;
load path=fmt aa2=ces3_10;
{ci2}=bonf1(ci1,0.08,aa1,aa2,dhat1);
ci2;
@aa1[121,9]~aa1[121,35];@
*/
