
/* GE OCt94 proc to return Bonferroni confidence intervals using the
matrices held in /FMT.  This version does the result for a single
value of c, which is a1=100%

Input :   cl,cu    : upper and lower (1-a1)% confidence intervals
                     from first stage
          a2       : second stage size
          aa1      : ces3 matrix (lower)
          aa2      : ces3 matrix (upper)
          delt     : estimate of delta

Output    bl,bu    : upper and lower (1-a2)% confidence intervals

e.g.  proc(1) = bonf1(-10|0.4,8,0.8);
   this will return the bonferroni cv's where the first stage test size
   was 2% and the second 8% (overall 10%) when delta is 0.8.
*/

proc(1) = exac(cl,a2,ss1,ss2,delt);

local e1, indl, cv1, cv2, p1, p2, pct, coll,
      colu, cvl1, cvu1, cvl2, cvu2, xv, cvl,
      cvu;

@ Select Range of c to consider @
@ deals with endpoints @
if cl<-39.9; cl=-39.9; endif;
if cl>9.4; cl=9.4; endif;

@ selects dist of tgamm inside 1st stage -do for upper and lower@
e1=ss1[.,1].<cl;
if cl>=-39.9;
indl=sumc(e1);
if abs(delt)>=0.1;
cv1=lint(cl,ss1[indl:indl+1,.],ss1[indl:indl+1,1]);
else;cv1=ss1[1,.];endif;
cv2=lint(cl,ss2[indl:indl+1,.],ss2[indl:indl+1,1]);
endif;


@ find column number for correct size @
p1=seqa(0.005,0.005,20);
p2=seqa(0.90,0.005,20);
pct=p1|0.5|p2;
pct=round(1000*pct)/1000;
coll=indnv(a2/2,pct)+1;
colu=indnv((1-(a2/2)),pct)+1;

cvl1=(cv1[.,coll]);
cvu1=(cv1[.,colu]);
cvl2=(cv2[.,coll]);
cvu2=(cv2[.,colu]);


@ interpolate according to delta @
xv=floor(delt*10)|ceil(delt*10);
if (10*delt)==xv[1,1]; cvl=cvl1';  cvu=cvu1';
elseif (10*delt)==xv[2,1]; cvl=cvl2'; cvu=cvu2';
else;
{cvl} = lint(delt*10,(cvl1')|(cvl2'),xv);
{cvu} = lint(delt*10,(cvu1')|(cvu2'),xv);
endif;


retp(sortc((delt/abs(delt)).*(cvl|cvu),1));
endp;

/*
/* debug */
#include ces.prc;
ci1=-1;
dhat1=0.1;
load path=fmt aa1=ces3_10;
load path=fmt aa2=ces3_20;
{ci2}=exac(ci1,0.08,aa1,aa2,dhat1);
ci2;
@aa1[121,9]~aa1[121,35];@
*/
